@@ -179,7 +179,7 @@ class ThesaurusListViewActionsCellAdapter(object):
     def content(self):
         if not ISecurityManager(self.context).canUsePermission('ztfy.ManageThesaurus'):
             return ''
-        klass = "ui-workflow ui-icon ui-icon-trash"
+        klass = "ui-workflow icon icon-trash"
         intids = getUtility(IIntIds)
         return '''<span class="%s" title="%s" onclick="$.ZTFY.thesaurus.remove(%s,this);"></span>''' % (klass,
                                                                                                         translate(_("Delete thesaurus"), context=self.request),
@@ -356,7 +356,7 @@ class ThesaurusExtractsListViewCellActions(object):
 
     @property
     def content(self):
-        klass = "ui-workflow ui-icon ui-icon-trash"
+        klass = "ui-workflow icon icon-trash"
         intids = getUtility(IIntIds)
         thesaurus = getParent(self.context, IThesaurus)
         addr = absoluteURL(IThesaurusExtracts(thesaurus), self.request)
